
class:bindHook('ToME:load', function(self, data)
	local Talents = require 'engine.interface.ActorTalents'
	local TD = Talents.talents_def
  
	local DamageType = require "engine.DamageType"
	local Dialog = require "engine.ui.Dialog"


TD.T_BODIES_RESERVE.getMax = function(self, t) return math.min(15, math.ceil(2 * self:getTalentLevel(t)) + 2) end
TD.T_BODIES_RESERVE.info = function(self, t)
	return ([[Your mind is so powerful it can bend reality, providing you with an extra-natural #{italic}#storage#{normal}# for bodies you snatch.
	You can store up to %d bodies.]]):
	format(t.getMax(self, t))
end


TD.T_CANNIBALIZE.action = function(self, t)
	local eff = self:hasEffect(self.EFF_POSSESSION)		
	local body = self:talentDialog(require("mod.dialogs.AssumeForm").new(self, t, "cannibalize", {filter_rank=eff.body.rank or 1, exclude_body=eff.body}))
	if not body then return false end
	if body.rank < eff.body.rank then game.logPlayer(self, "Rank of body too low.") return false end

	self:callTalent(self.T_BODIES_RESERVE, "decreaseUse", body, false)

	local hp = t.getHeal(self, t) * body.max_life / 100
	eff.body._cannibalize_penalty = eff.body._cannibalize_penalty or 1
	hp = hp * eff.body._cannibalize_penalty
	eff.body._cannibalize_penalty = eff.body._cannibalize_penalty

	local old_no_healing = self.no_healing
	self.no_healing = nil -- This even bypasses no healing set by npcs
	local oldlife = self.life
	self:heal(hp)
	eff.can_raise_life_over = eff.can_raise_life_over + (self.life - oldlife)
	self.no_healing = old_no_healing
	self:incPsi(hp * 0.5)

	game:playSoundNear(self, "talents/spell_generic2")
	return true
end

TD.T_CANNIBALIZE.info = function(self, t)
	return ([[When you assume a form you may cannibalize a body in your reserve to replenish your current body.
	You can only use bodies that are of same or higher rank for the effect to work.
	Your current body will heal for %d%% of the max life of the cannibalized one and you will also regenerate 50%% of this value as psi.
	The healing effect is more psionic in nature than a real heal. As such may things that prevent healing will not prevent cannibalize from working.
	Cannibalize is the only possible way to heal a body.
	]]):
	format(t.getHeal(self, t))
end


TD.T_ASSUME_FORM.speed_type = special_combat
TD.T_ASSUME_FORM.no_energy = true
TD.T_ASSUME_FORM.info = function(self, t)
	return ([[You call upon one of your reserve bodies, assuming its form.
	A body used this way may not be healed in any way.
	You can choose to exit the body at any moment by using this talent again, returning it to your reserve as it is.
	When you reach 0 life you are forced out of it and the shock deals %d%% of the maximum life of your normal body to you while reducing your movement speed by 50%% and your damage by 60%% for 6 turns.
	The cooldown only starts when you resume your normal form.
	While in another body all experience you gain still goes to you but will not be applied until you revert back.
	While in another body your currently equiped objects are #{italic}#merged#{normal}# in you, you can not take them of or wear new ones.
	Bodies possessed:
	%s]]):
	format(self:callTalent(self.T_POSSESS, "getShock"), bodies_desc(self))
end

--range = function(self, t) return 3 + math.floor(self:getTalentLevel(t) * 0.5 - 0.5) end,

TD.T_POSSESS.Range = function(self, t) return 3 + math.floor(self:getTalentLevel(t) * 0.5 - 0.5) end
TD.T_POSSESS.allowedTypes = function(self, t, type)
    return true
 end
TD.T_POSSESS.info = function(self, t)
	local fake = {rank=2}
	local rt0, rc0 = self.TextRank(fake)
	fake.rank = 3; local rt3, rc3 = self.TextRank(fake)
	fake.rank = 3.5; local rt5, rc5 = self.TextRank(fake)
	fake.rank = 4; local rt7, rc7 = self.TextRank(fake)

	return ([[You cast a psionic web at a target that lasts for %d turns. Each turn it deals %0.2f mind damage.
	If the target dies with the web in place you will capture its body and store it in a hidden psionic reserve.
	At any further time you can use the Assume Form talent to temporarily shed your own body and assume your new form, strengths and weaknesses both.
	You may only use this power if you have room for a new body in your storage.

	You may only steal the body of creatures of the following rank %s%s#LAST# or lower.
	At level 3 up to rank %s%s#LAST#.
	At level 5 up to rank %s%s#LAST#.
	At level 7 up to rank %s%s#LAST#.]])
	:
		format(
			t.getDur(self, t), damDesc(self, DamageType.MIND, t.getDamage(self, t)),
			rc0, rt0, rc3, rt3, rc5, rt5, rc7, rt7
		)
end

TD.T_FULL_CONTROL.info = function(self, t)
	return ([[When you assume the form of an other body you gain more control over the body:
	- at level 1 you gain one more talent slot
	- at level 2 you gain one more talent slot
	- at level 3 you gain resistances and flat resistances
	- at level 4 you gain one more talent slot
	- at level 5 you gain all speeds (only if they are superior to yours)
	- at level 6+ you gain one more talent slot
	]]):
	format(t.getNbTalents(self, t))
end

end)